<!DOCTYPE html>
<html lang="en">

<!-- Mirrored from seoc-html-v2.vercel.app/team.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:42:23 GMT -->
<!-- Added by HTTrack --><meta http-equiv="content-type" content="text/html;charset=utf-8" /><!-- /Added by HTTrack -->
<head>
     <meta charset="UTF-8">
     <meta name="viewport" content="width=device-width, initial-scale=1.0">
     <title>SEO - Digital Marketing Agency</title>

     <!--=====FAB ICON=======-->
    <link rel="shortcut icon" href="assets/img/logo/fav-logo1.png" type="image/x-icon">

    <!--===== CSS LINK =======-->
    <link rel="stylesheet" href="assets/css/plugins/bootstrap.min.css">
    <link rel="stylesheet" href="assets/css/plugins/aos.css">
    <link rel="stylesheet" href="assets/css/plugins/fontawesome.css">
    <link rel="stylesheet" href="assets/css/plugins/magnific-popup.css">
    <link rel="stylesheet" href="assets/css/plugins/mobile.css">
    <link rel="stylesheet" href="assets/css/plugins/owlcarousel.min.css">
    <link rel="stylesheet" href="assets/css/plugins/sidebar.css">
    <link rel="stylesheet" href="assets/css/plugins/slick-slider.css">
    <link rel="stylesheet" href="assets/css/plugins/nice-select.css">
    <link rel="stylesheet" href="assets/css/main.css">

    <!--=====  JS SCRIPT LINK =======-->
    <script src="assets/js/plugins/jquery-3-6-0.min.js"></script>
</head>
<body class="homepage1-body">

<!--===== PRELOADER STARTS =======-->
<div class="preloader">
  <div class="loading-container">
    <div class="loading"></div>
    <div id="loading-icon"><img src="assets/img/logo/preloader.png" alt=""></div>
  </div>
</div>
<!--===== PRELOADER ENDS =======-->

<!--===== PROGRESS STARTS=======-->
<div class="paginacontainer">
     <div class="progress-wrap">
       <svg class="progress-circle svg-content" width="100%" height="100%" viewBox="-1 -1 102 102">
         <path d="M50,1 a49,49 0 0,1 0,98 a49,49 0 0,1 0,-98"/>
       </svg>
     </div>
   </div>
 <!--===== PROGRESS ENDS=======-->

   <!--=====HEADER START=======-->
   <header>
    <div class="header-area homepage1 header header-sticky d-none d-lg-block " id="header">
      <div class="container">
        <div class="row">
          <div class="col-lg-12">
            <div class="header-elements">
              <div class="site-logo">
                <a href="index.html"><img src="assets/img/logo/logo1.png" alt=""></a>
              </div>
              <div class="main-menu">
                <ul>
                  <li><a href="#">Home <i class="fa-solid fa-angle-down"></i></a>
                    <div class="tp-submenu">
                      <div class="row">
                         <div class="col-lg-12">
                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img1.png" alt="">
                                </div>
                          
                                 <div class="homemenu-btn">
                                    <a class="header-btn1" href="index.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn1" href="single-index1.html" target="_blank">One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="404.html">SEO & Digital Marketing 01</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img2.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn1" href="index2.html" target="_blank"> Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn1" href="single-index2.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index2.html">SEO & Digital Marketing 02</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/comming-soon.png" alt="" class="commingsoon">
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn1" href="index3.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn1" href="single-index3.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index3.html">SEO & Digital Marketing 03</a>
                               </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img3.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn1" href="index4.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn1" href="single-index4.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index4.html">SEO & Digital Marketing 04</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img4.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn1" href="index5.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn1" href="single-index5.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index5.html">SEO & Digital Marketing 05</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img11.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn1" href="index11.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn1" href="single-index11.html" target="_blank">One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index11.html">Staffing Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img12.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn1" href="index12.html" target="_blank"> Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn1" href="single-index12.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index12.html">Consulting Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img13.png" alt="" class="commingsoon">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn1" href="index13.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn1" href="single-index13.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index13.html">Advertising Agency</a>
                               </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img14.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn1" href="index14.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn1" href="single-index14.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index14.html">IT Solution Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img15.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn1" href="index15.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn1" href="single-index15.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index15.html">Startup Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img5.png" alt="">
                                </div>
                            
                                 <div class="homemenu-btn">
                                    <a class="header-btn1" href="index6.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn1" href="single-index6.html" target="_blank">One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index6.html">SEO & Digital Marketing 06</a>
                                 </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img6.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn1" href="index7.html" target="_blank"> Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn1" href="single-index7.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index7.html">SEO & Digital Marketing 07</a>
                                 </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img7.png" alt="" class="commingsoon">
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn1" href="index8.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn1" href="single-index8.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index8.html">SEO & Digital Marketing 08</a>
                               </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img8.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn1" href="index9.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn1" href="single-index9.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index9.html">SEO & Digital Marketing 09</a>
                                 </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img9.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>HOT</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn1" href="index10.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn1" href="single-index10.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index10.html">SEO & Digital Marketing 10</a>
                                 </div>
                              </div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img17.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index6.html">Creative Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img16.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index7.html">Digital Marketing Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img18.png" alt="" class="commingsoon">
                                </div>
                               <div class="homemenu-content">
                                <a href="index8.html">Digital Marketer Agency</a>
                               </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img19.png" alt="">
                                </div>
  
                                 <div class="homemenu-content">
                                  <a href="index9.html">Corporate Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img20.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index10.html">Coming Soon</a>
                                 </div>
                              </div>
                            </div>
                          </div>
                         </div>
                      </div>
                   </div>
                  </li>
                  <li><a href="about.html">About</a></li>
                  <li><a href="#">Services <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="service1.html">Service One</a></li>
                      <li><a href="service2.html">Service Two</a></li>
                      <li><a href="service3.html">Service Three</a></li>
                      <li><a href="service4.html">Service Four</a></li>
                      <li><a href="service5.html">Service Five</a></li>
                    </ul>
                  </li>
                  <li><a href="#">Blogs <i class="fa-solid fa-angle-down"></i></a>
                  <ul class="dropdown-padding">
                    <li><a href="blog.html">Blog One</a></li>
                    <li><a href="blog-left.html">Blog Left</a></li>
                    <li><a href="blog-right.html">Blog Right</a></li>
                    <li><a href="blog-single.html">Blog Single</a></li>
                  </ul>
                  </li>
                  <li><a href="#">Pages <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="case.html">Case Study</a></li>
                      <li><a href="case-single.html">Case Study Single</a></li>
                      <li><a href="team.html">Our Team</a></li>
                      <li><a href="pricing.html">Pricing Plan</a></li>
                      <li><a href="testimonials.html">Testimonials</a></li>
                      <li><a href="faq.html">FAQ</a></li>
                      <li><a href="404-2.html">404</a></li>
                    </ul>
                  </li>
                  <li><a href="contact.html">Contact Us</a></li>
                </ul>
              </div>
              <div class="btn-area">
                <div class="search-icon header__search header-search-btn">
                  <a href="#"><img src="assets/img/icons/search-icons1.svg" alt=""></a>
                </div>
                <a href="contact.html" class="header-btn1">Free Consultation <span><i class="fa-solid fa-arrow-right"></i></span></a>
              </div>

              <div class="header-search-form-wrapper">
                <div class="tx-search-close tx-close"><i class="fa-solid fa-xmark"></i></div>
                <div class="header-search-container">
                    <form role="search" class="search-form">
                    <input type="search"  class="search-field" placeholder="Search …" value="" name="s">
                    <button type="submit" class="search-submit"><img src="assets/img/icons/search-icons1.svg" alt=""></button>
                    </form>
                </div>
            </div>
            <div class="body-overlay"></div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </header>
  <!--=====HEADER END =======-->

  <!--===== MOBILE HEADER STARTS =======-->
 <div class="mobile-header mobile-haeder1 d-block d-lg-none">
  <div class="container-fluid">
    <div class="col-12">
      <div class="mobile-header-elements">
        <div class="mobile-logo">
          <a href="index.html"><img src="assets/img/logo/logo1.png" alt=""></a>
        </div>
        <div class="mobile-nav-icon dots-menu">
          <i class="fa-solid fa-bars"></i>
        </div>
      </div>
    </div>
  </div>
</div>

<div class="mobile-sidebar mobile-sidebar1">
  <div class="logosicon-area">
    <div class="logos">
      <img src="assets/img/logo/logo1.png" alt="">
    </div>
    <div class="menu-close">
      <i class="fa-solid fa-xmark"></i>
    </div>
   </div>
  <div class="mobile-nav mobile-nav1">
    <ul class="mobile-nav-list nav-list1">
      <li><a href="#" >Home </a>
        <ul class="sub-menu">
          <li>
            <a href="#">Multiple Page</a>
            <ul class="sub-menu">
              <li><a href="index.html">Home One</a></li>
              <li><a href="index2.html">Home Two</a></li>
              <li><a href="index3.html">Home Three</a></li>
              <li><a href="index4.html">Home Four</a></li>
              <li><a href="index5.html">Home Five</a></li>
              <li><a href="index6.html">Home Six</a></li>
              <li><a href="index7.html">Home Seven</a></li>
              <li><a href="index8.html">Home Eight</a></li>
              <li><a href="index9.html">Home Nine</a></li>
              <li><a href="index10.html">Home Ten</a></li>
              <li><a href="index11.html">Home Eleven</a></li>
              <li><a href="index12.html">Home Twelve</a></li>
              <li><a href="index13.html">Home Thirteen</a></li>
              <li><a href="index14.html">Home Fouteen</a></li>
              <li><a href="index15.html">Home Fifteen</a></li>
            </ul>
          </li>
          <li>
            <a href="#">Landing Page</a>
            <ul class="sub-menu">
              <li><a href="single-index1.html" target="_blank">Home One</a></li>
              <li><a href="single-index2.html" target="_blank">Home Two</a></li>
              <li><a href="single-index3.html" target="_blank">Home Three</a></li>
              <li><a href="single-index4.html" target="_blank">Home Four</a></li>
              <li><a href="single-index5.html" target="_blank">Home Five</a></li>
              <li><a href="single-index6.html" target="_blank">Home Six</a></li>
              <li><a href="single-index7.html" target="_blank">Home Seven</a></li>
              <li><a href="single-index8.html" target="_blank">Home Eight</a></li>
              <li><a href="single-index9.html" target="_blank">Home Nine</a></li>
              <li><a href="single-index10.html" target="_blank">Home Ten</a></li>
              <li><a href="single-index11.html" target="_blank">Home Eleven</a></li>
              <li><a href="single-index12.html" target="_blank">Home Twelve</a></li>
              <li><a href="single-index13.html" target="_blank">Home Thirteen</a></li>
              <li><a href="single-index14.html" target="_blank">Home Fouteen</a></li>
              <li><a href="single-index15.html" target="_blank">Home Fifteen</a></li>
            </ul>
          </li>
        </ul>
      </li>
      <li><a href="about.html">About</a></li>
      <li><a href="404-3.html">Services</a>
        <ul class="sub-menu">
          <li><a href="service1.html">Service One</a></li>
          <li><a href="service2.html">Service Two</a></li>
          <li><a href="service3.html">Service Three</a></li>
          <li><a href="service4.html">Service Four</a></li>
          <li><a href="service5.html">Service Five</a></li>
        </ul>
      </li>
      <li><a href="#">Blogs</a>
        <ul class="sub-menu">
          <li><a href="blog.html">Blog One</a></li>
          <li><a href="blog-left.html">Blog Left</a></li>
          <li><a href="blog-right.html">Blog Right</a></li>
          <li><a href="blog-single.html">Blog Single</a></li>
        </ul>
      </li>
      <li><a href="#">Pages</a>
        <ul class="sub-menu">
          <li><a href="case.html">Case Study One</a></li>
          <li><a href="case-single.html">Case Study Single</a></li>
          <li><a href="team.html">Our Team</a></li>
          <li><a href="pricing.html">Pricing Plan</a></li>
          <li><a href="testimonials.html">Testimonials</a></li>
          <li><a href="faq.html">FAQ</a></li>
          <li><a href="404-2.html">404</a></li>
        </ul>
      </li>
      <li><a href="contact.html">Contact Us</a></li>
    </ul>

    <div class="allmobilesection">
      <a href="contact.html"  class="header-btn1">Get Started <span><i class="fa-solid fa-arrow-right"></i></span></a>
      <div class="single-footer">
        <h3>Contact Info</h3>
        <div class="footer1-contact-info">
          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-phone-volume"></i>
            </div>
            <div class="contact-info-text">
              <a href="tel:+3(924)4596512">+3(924)4596512</a>
            </div>
          </div>

          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-envelope"></i>
            </div>
            <div class="contact-info-text">
              <a href="mailto:info@example.com">info@example.com</a>
            </div>
          </div>

          <div class="single-footer">
            <h3>Our Location</h3>
            
            <div class="contact-info-single">
              <div class="contact-info-icon">
                <i class="fa-solid fa-location-dot"></i>
              </div>
              <div class="contact-info-text">
                <a href="mailto:info@example.com" >55 East Birchwood Ave.Brooklyn, <br> New York 11201,United States</a>
              </div>
            </div>

          </div>
          <div class="single-footer">
            <h3>Social Links</h3>
            
            <div class="social-links-mobile-menu">
              <ul>
                <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
              </ul>
            </div>
          </div>
        </div>
      </div>
     </div>
  </div>
</div>
<!--===== MOBILE HEADER STARTS =======-->

<!--===== HERO AREA STARTS =======-->
<div class="about-header-area" style="background-image: url(assets/img/bg/inner-header.png); background-repeat: no-repeat; background-size: cover; background-position: center;">
    <img src="assets/img/elements/elements1.png" alt="" class="elements1 aniamtion-key-1">
    <img src="assets/img/elements/star2.png" alt="" class="star2 keyframe5">
    <div class="container">
        <div class="row">
            <div class="col-lg-8 m-auto">
                <div class="about-inner-header heading9 text-center">
                    <h1>Meet The Team Member</h1>
                    <a href="index.html">Home <i class="fa-solid fa-angle-right"></i><span>Meet The Team</span></a>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== HERO AREA ENDS =======-->

<!--===== TEAM AREA STARTS =======-->
<div class="team-inner-section-area sp1">
    <div class="container">
        <div class="row align-items-center">
            <div class="col-lg-5">
                <div class="team-header heading2">
                    <h5>What We Believe In</h5>
                    <h2>We Believe In Marketing The World A Better Place </h2>
                </div>
            </div>
            <div class="col-lg-2"></div>
            <div class="col-lg-5">
                <div class="pera heading2">
                    <p>We achieve this by scaling impactful businesses. Our focus is on promoting our clients’ brands and effectively disseminating their message worldwide. We refuse to settle for the status quo, constantly striving to expand our own business with the same level of honesty and integrity we employ to enhance our clients’ enterprises.</p>
                </div>
            </div>
            <div class="col-lg-12">
                <div class="space50"></div>
                <div class="step-by-step">
                    <div class="row">
                        <div class="col-lg-3">
                            <div class="pera">
                                <p>Transparency</p>
                            </div>
                        </div>

                        <div class="col-lg-3">
                            <div class="pera">
                                <p>Accountability</p>
                            </div>
                        </div>

                        <div class="col-lg-3">
                            <div class="pera">
                                <p>Lifelong Learning</p>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="pera">
                                <p>Ambition</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== TEAM AREA ENDS =======-->

<!--===== TEAM AREA STARTS =======-->
<div class="team-inner-section-area sp2 bg2">
    <div class="container">
      <div class="row">
        <div class="col-lg-6">
          <div class="team2-header-area heading2">
            <h2>Executive Team</h2>
          </div>
        </div>
      </div>
      <div class="row">
        <div class="col-lg-3 col-md-6">
          <div class="team-boxarea">
            <div class="img1">
              <img src="assets/img/all-images/team-img1.png" alt="">
            </div>
            <ul>
              <li><a href="#"><img src="assets/img/icons/facebook.svg" alt=""></a></li>
              <li><a href="#"><img src="assets/img/icons/instagram.svg" alt=""></a></li>
              <li><a href="#"><img src="assets/img/icons/linkedin.svg" alt=""></a></li>
              <li><a href="#" class="m-0"><img src="assets/img/icons/youtube.svg" alt=""></a></li>
            </ul>
            <div class="content">
              <a href="team.html">John Doe</a>
              <p>CEO & Founder</p>
            </div>
          </div>
        </div>
  
        <div class="col-lg-3 col-md-6">
          <div class="team-boxarea">
            <div class="img1">
              <img src="assets/img/all-images/team-img2.png" alt="">
            </div>
            <ul>
                <li><a href="#"><img src="assets/img/icons/facebook.svg" alt=""></a></li>
                <li><a href="#"><img src="assets/img/icons/instagram.svg" alt=""></a></li>
                <li><a href="#"><img src="assets/img/icons/linkedin.svg" alt=""></a></li>
                <li><a href="#" class="m-0"><img src="assets/img/icons/youtube.svg" alt=""></a></li>
            </ul>
            <div class="content">
              <a href="team.html">Jane Smith</a>
              <p>Digital Marketing Officer</p>
            </div>
          </div>
        </div>
  
        <div class="col-lg-3 col-md-6">
          <div class="team-boxarea">
            <div class="img1">
              <img src="assets/img/all-images/team-img3.png" alt="">
            </div>
            <ul>
                <li><a href="#"><img src="assets/img/icons/facebook.svg" alt=""></a></li>
                <li><a href="#"><img src="assets/img/icons/instagram.svg" alt=""></a></li>
                <li><a href="#"><img src="assets/img/icons/linkedin.svg" alt=""></a></li>
                <li><a href="#" class="m-0"><img src="assets/img/icons/youtube.svg" alt=""></a></li>
            </ul>
            <div class="content">
              <a href="team.html">Sarah Thompson </a>
              <p>Web Designer</p>
            </div>
          </div>
        </div>
  
        <div class="col-lg-3 col-md-6">
          <div class="team-boxarea m-0">
            <div class="img1">
              <img src="assets/img/all-images/team-img4.png" alt="">
            </div>
            <ul>
                <li><a href="#"><img src="assets/img/icons/facebook.svg" alt=""></a></li>
                <li><a href="#"><img src="assets/img/icons/instagram.svg" alt=""></a></li>
                <li><a href="#"><img src="assets/img/icons/linkedin.svg" alt=""></a></li>
                <li><a href="#" class="m-0"><img src="assets/img/icons/youtube.svg" alt=""></a></li>
            </ul>
            <div class="content">
              <a href="team.html">David Garcia</a>
              <p>Content Writer</p>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
<!--===== TEAM AREA ENDS =======-->

<!--===== TESTIMONIAL AREA STARTS =======-->
<div class="testimonial1-section-area sp1">
    <div class="container">
      <div class="row align-items-center">
        <div class="col-lg-12">
          <div class="testimonial-sliders">
               <div class="row align-items-center">
                <div class="col-lg-6">
                  <div class="testimonial-content-slider slider-nav1">
                    <div class="testimonial-slider-boxarea">
                        <img src="assets/img/icons/quito3.svg" alt="">
                        <div class="space24"></div>
                         <div class="testimonial5-all-content">
                            <p>"I can't say enough about the incredible results we've achieved with SEOC. Their SEO expertise has catapulted our website to the top of search engine rankings, resulting in a significant increase in organic traffic and leads. I highly recommend SEOC to any business looking to boost their visibility and drive growth online."</p>
                         </div>
                         <div class="space32"></div>
                         <div class="content">
                            <a href="team.html">Anderson Belly</a>
                            <p>Head Of Google Ads</p>
                          </div>
                        </div>

                        <div class="testimonial-slider-boxarea">
                            <img src="assets/img/icons/quito3.svg" alt="">
                            <div class="space24"></div>
                             <div class="testimonial5-all-content">
                                <p>"I can't say enough about the incredible results we've achieved with SEOC. Their SEO expertise has catapulted our website to the top of search engine rankings, resulting in a significant increase in organic traffic and leads. I highly recommend SEOC to any business looking to boost their visibility and drive growth online."</p>
                             </div>
                             <div class="space32"></div>
                             <div class="content">
                                <a href="team.html">Anderson Belly</a>
                                <p>Head Of Google Ads</p>
                              </div>
                            </div>

                            <div class="testimonial-slider-boxarea">
                                <img src="assets/img/icons/quito3.svg" alt="">
                                <div class="space24"></div>
                                 <div class="testimonial5-all-content">
                                    <p>"I can't say enough about the incredible results we've achieved with SEOC. Their SEO expertise has catapulted our website to the top of search engine rankings, resulting in a significant increase in organic traffic and leads. I highly recommend SEOC to any business looking to boost their visibility and drive growth online."</p>
                                 </div>
                                 <div class="space32"></div>
                                 <div class="content">
                                    <a href="team.html">Anderson Belly</a>
                                    <p>Head Of Google Ads</p>
                                  </div>
                                </div>
                                <div class="testimonial-slider-boxarea">
                                    <img src="assets/img/icons/quito3.svg" alt="">
                                    <div class="space24"></div>
                                     <div class="testimonial5-all-content">
                                        <p>"I can't say enough about the incredible results we've achieved with SEOC. Their SEO expertise has catapulted our website to the top of search engine rankings, resulting in a significant increase in organic traffic and leads. I highly recommend SEOC to any business looking to boost their visibility and drive growth online."</p>
                                     </div>
                                     <div class="space32"></div>
                                     <div class="content">
                                        <a href="team.html">Anderson Belly</a>
                                        <p>Head Of Google Ads</p>
                                      </div>
                                    </div>
                            </div>
                  <div class="testimonial-arrows">
                    <div class="testimonial-prev-arrow">
                      <button><i class="fa-solid fa-arrow-left"></i></button>
                    </div>
                    <div class="testimonial-next-arrow">
                      <button><i class="fa-solid fa-arrow-right"></i></button>
                    </div>
                  </div>
                </div>
  
                <div class="col-lg-6">
                  <div class="teimonial-slider-nav-area foter-carousel">
                    <div class="testimonial-slider-img">
                      <img src="assets/img/all-images/testimonial-img10.png" alt="">
                    </div>
                    <div class="testimonial-slider-img">
                        <img src="assets/img/all-images/testimonial-img10.png" alt="">
                    </div>
                    <div class="testimonial-slider-img">
                        <img src="assets/img/all-images/testimonial-img10.png" alt="">
                    </div>
                    <div class="testimonial-slider-img">
                        <img src="assets/img/all-images/testimonial-img10.png" alt="">
                    </div>
                    <div class="testimonial-slider-img">
                        <img src="assets/img/all-images/testimonial-img10.png" alt="">
                    </div>
                    <div class="testimonial-slider-img">
                        <img src="assets/img/all-images/testimonial-img10.png" alt="">
                    </div>
                  </div>
                </div>
               </div>
            </div>
        </div>
      </div>
    </div>
  </div>
<!--===== TESTIMONIAL AREA ENDS =======-->

<!--===== TEAM AREA STARTS =======-->
<div class="team-inner-section-area sp2 bg2">
    <div class="container">
      <div class="row">
        <div class="col-lg-6">
          <div class="team2-header-area heading2">
            <h2>Leadership</h2>
          </div>
        </div>
      </div>
      <div class="row">
        <div class="col-lg-3 col-md-6">
          <div class="team-boxarea">
            <div class="img1">
              <img src="assets/img/all-images/team-img1.png" alt="">
            </div>
            <ul>
              <li><a href="#"><img src="assets/img/icons/facebook.svg" alt=""></a></li>
              <li><a href="#"><img src="assets/img/icons/instagram.svg" alt=""></a></li>
              <li><a href="#"><img src="assets/img/icons/linkedin.svg" alt=""></a></li>
              <li><a href="#" class="m-0"><img src="assets/img/icons/youtube.svg" alt=""></a></li>
            </ul>
            <div class="content">
              <a href="team.html">John Doe</a>
              <p>CEO & Founder</p>
            </div>
          </div>
          <div class="space30"></div>
        </div>
        
        <div class="col-lg-3 col-md-6">
          <div class="team-boxarea">
            <div class="img1">
              <img src="assets/img/all-images/team-img2.png" alt="">
            </div>
            <ul>
                <li><a href="#"><img src="assets/img/icons/facebook.svg" alt=""></a></li>
                <li><a href="#"><img src="assets/img/icons/instagram.svg" alt=""></a></li>
                <li><a href="#"><img src="assets/img/icons/linkedin.svg" alt=""></a></li>
                <li><a href="#" class="m-0"><img src="assets/img/icons/youtube.svg" alt=""></a></li>
            </ul>
            <div class="content">
              <a href="team.html">Jane Smith</a>
              <p>Digital Marketing Officer</p>
            </div>
          </div>
          <div class="space30"></div>
        </div>
  
        <div class="col-lg-3 col-md-6">
          <div class="team-boxarea">
            <div class="img1">
              <img src="assets/img/all-images/team-img3.png" alt="">
            </div>
            <ul>
                <li><a href="#"><img src="assets/img/icons/facebook.svg" alt=""></a></li>
                <li><a href="#"><img src="assets/img/icons/instagram.svg" alt=""></a></li>
                <li><a href="#"><img src="assets/img/icons/linkedin.svg" alt=""></a></li>
                <li><a href="#" class="m-0"><img src="assets/img/icons/youtube.svg" alt=""></a></li>
            </ul>
            <div class="content">
              <a href="team.html">Sarah Thompson </a>
              <p>Web Designer</p>
            </div>
          </div>
          <div class="space30"></div>
        </div>
  
        <div class="col-lg-3 col-md-6">
          <div class="team-boxarea">
            <div class="img1">
              <img src="assets/img/all-images/team-img4.png" alt="">
            </div>
            <ul>
                <li><a href="#"><img src="assets/img/icons/facebook.svg" alt=""></a></li>
                <li><a href="#"><img src="assets/img/icons/instagram.svg" alt=""></a></li>
                <li><a href="#"><img src="assets/img/icons/linkedin.svg" alt=""></a></li>
                <li><a href="#" class="m-0"><img src="assets/img/icons/youtube.svg" alt=""></a></li>
            </ul>
            <div class="content">
              <a href="team.html">David Garcia</a>
              <p>Content Writer</p>
            </div>
          </div>
          <div class="space30"></div>
        </div>

        <div class="col-lg-3 col-md-6">
            <div class="team-boxarea">
              <div class="img1">
                <img src="assets/img/all-images/team-img9.png" alt="">
              </div>
              <ul>
                  <li><a href="#"><img src="assets/img/icons/facebook.svg" alt=""></a></li>
                  <li><a href="#"><img src="assets/img/icons/instagram.svg" alt=""></a></li>
                  <li><a href="#"><img src="assets/img/icons/linkedin.svg" alt=""></a></li>
                  <li><a href="#" class="m-0"><img src="assets/img/icons/youtube.svg" alt=""></a></li>
              </ul>
              <div class="content">
                <a href="team.html">Florence Walker</a>
                <p>Future Creative Director</p>
              </div>
            </div>
            <div class="space30"></div>
          </div>

          <div class="col-lg-3 col-md-6">
            <div class="team-boxarea">
              <div class="img1">
                <img src="assets/img/all-images/team-img10.png" alt="">
              </div>
              <ul>
                  <li><a href="#"><img src="assets/img/icons/facebook.svg" alt=""></a></li>
                  <li><a href="#"><img src="assets/img/icons/instagram.svg" alt=""></a></li>
                  <li><a href="#"><img src="assets/img/icons/linkedin.svg" alt=""></a></li>
                  <li><a href="#" class="m-0"><img src="assets/img/icons/youtube.svg" alt=""></a></li>
              </ul>
              <div class="content">
                <a href="team.html">Sally Mann</a>
                <p>Designer</p>
              </div>
            </div>
            <div class="space30"></div>
          </div>

          <div class="col-lg-3 col-md-6">
            <div class="team-boxarea">
              <div class="img1">
                <img src="assets/img/all-images/team-img11.png" alt="">
              </div>
              <ul>
                  <li><a href="#"><img src="assets/img/icons/facebook.svg" alt=""></a></li>
                  <li><a href="#"><img src="assets/img/icons/instagram.svg" alt=""></a></li>
                  <li><a href="#"><img src="assets/img/icons/linkedin.svg" alt=""></a></li>
                  <li><a href="#" class="m-0"><img src="assets/img/icons/youtube.svg" alt=""></a></li>
              </ul>
              <div class="content">
                <a href="team.html">Miss Darrin Larkin</a>
                <p>Orchestrator</p>
              </div>
            </div>
            <div class="space30"></div>
          </div>

          <div class="col-lg-3 col-md-6">
            <div class="team-boxarea">
              <div class="img1">
                <img src="assets/img/all-images/team-img12.png" alt="">
              </div>
              <ul>
                  <li><a href="#"><img src="assets/img/icons/facebook.svg" alt=""></a></li>
                  <li><a href="#"><img src="assets/img/icons/instagram.svg" alt=""></a></li>
                  <li><a href="#"><img src="assets/img/icons/linkedin.svg" alt=""></a></li>
                  <li><a href="#" class="m-0"><img src="assets/img/icons/youtube.svg" alt=""></a></li>
              </ul>
              <div class="content">
                <a href="team.html">David Garcia</a>
                <p>Coordinator</p>
              </div>
            </div>
          </div>
      </div>
    </div>
  </div>
<!--===== TEAM AREA ENDS =======-->

<!--===== WORK AREA STARTS =======-->
<div class="works-inner-section-area sp1">
    <div class="container">
        <div class="row align-items-center">
            <div class="col-lg-6">
                <div class="about-all-images-area">
                    <img src="assets/img/elements/elements14.png" alt="" class="elements12 keyframe5">
                    <img src="assets/img/elements/elements15.png" alt="" class="elements13 keyframe5">
                    <div class="row">
                      <div class="col-lg-6 col-md-6">
                        <div class="img1 ">
                            <div class="space100"></div>
                          <img src="assets/img/all-images/about-img6.png" alt="">
                        </div>
                      </div>
                      <div class="col-lg-6 col-md-6">
                        <div class="img2 ">
                          <img src="assets/img/all-images/service-img5.png" alt="">
                        </div>
                      </div>
                    </div>
                  </div>
            </div>
            <div class="col-lg-5">
                <div class="works-header-area heading2 specing2">
                    <h5>Our Mission</h5>
                    <h2>Our Mission</h2>
                    <p>We strive to be more than just a service provider; we aim to be trusted SEOC By staying true to our mission and values, we are committed to helping businesses of all sizes achieve their goals, realize their potential shape.</p>
                    <div class="space32"></div>
                    <div class="btn-area1">
                        <a href="case.html" class="header-btn1">Our Case Study <span><i class="fa-solid fa-arrow-right"></i></span></a>
                    </div>
                </div>
            </div>
        </div>
        </div>
    </div>
<!--===== WORK AREA ENDS =======-->

<!--===== CTA AREA STARTS =======-->
<div class="cta-section-area">
  <img src="assets/img/bg/cta-bg1.png" alt="" class="cta-bg1 aniamtion-key-2">
  <img src="assets/img/bg/cta-bg2.png" alt="" class="cta-bg2 aniamtion-key-1">
  <div class="container">
    <div class="row">
      <div class="col-lg-12 m-auto">  
        <div class="cta-header-area text-center sp4 heading2">
          <h2>Ready To Take Your SEO To <br class="d-md-block d-none"> The Next Level</h2>
          <p>Effective SEO strategies not only elevate a website's visibility but also drive <br class="d-md-block d-none"> targeted traffic, enhance user experience,</p>
          <div class="btn-area text-center">
            <a href="contact.html" class="header-btn1">Free Consultation <span><i class="fa-solid fa-arrow-right"></i></span></a>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== CTA AREA ENDS =======-->

<!--===== FOOTER AREA STARTS =======-->
<div class="footer1-section-area">
  <div class="container">
    <div class="row">
      <div class="col-lg-3 col-md-6">
        <div class="footer-logo-area">
          <img src="assets/img/logo/logo1.png" alt="">
          <p>By optimizing content, leveraging relevant keywords, and adhering to best practices, businesses can secure prominent position (SEO)</p>
          <ul>
            <li><a href="#"><img src="assets/img/icons/facebook.svg" alt=""></a></li>
            <li><a href="#"><img src="assets/img/icons/instagram.svg" alt=""></a></li>
            <li><a href="#"><img src="assets/img/icons/linkedin.svg" alt=""></a></li>
            <li><a href="#"><img src="assets/img/icons/youtube.svg" alt=""></a></li>
          </ul>
        </div>
      </div>

      <div class="col-lg-2 col-md-6">
        <div class="footer-logo-area1">
          <h3>About Link</h3>
          <ul>
            <li><a href="blog.html">Our Blog</a></li>
            <li><a href="about.html">About Us</a></li>
            <li><a href="service1.html">Services</a></li>
            <li><a href="case.html">Marketing</a></li>
            <li><a href="testimonials.html">Testimonials</a></li>
            <li><a href="contact.html">Contact Us</a></li>
          </ul>
        </div>
      </div>

      <div class="col-lg-3 col-md-6">
        <div class="footer-logo-area2">
          <h3>Get in touch</h3>
          <ul>
            <li><a href="404-4.html"><img src="assets/img/icons/email.svg" alt=""><span>Infoseoc@gmail.com</span></a></li>
            <li><a href="#"><img src="assets/img/icons/location.svg" alt=""><span>8708 Technology Forest <br class="d-lg-block d-none"> Pl Suite 125 -G, The <br class="d-lg-block d-none"> Woodlands, TX 773</span></a></li>
            <li><a href="tel:123-456-7890"><img src="assets/img/icons/phone.svg" alt=""><span>123-456-7890</span></a></li>
          </ul>
        </div>
      </div>
      <div class="col-lg-4 col-md-6">
        <div class="footer-logo-area3">
          <h3>Subscribe Our Newsletter</h3>
          <form action="#">
            <input type="text" placeholder="Enter Your email">
            <button class="header-btn1"> Subscribe <span><i class="fa-solid fa-arrow-right"></i></span></button>
          </form>
        </div>
      </div>
    </div>
    <div class="space80 d-lg-block d-none"></div>
    <div class="space40 d-lg-none d-block"></div>
    <div class="row">
      <div class="col-lg-12">
        <div class="copyright-area">
          <div class="pera">
            <p>ⓒCopyright 2024 SEOC . All rights reserved</p>
          </div>
          <ul>
            <li><a href="#">Terms & Conditions</a></li>
            <li><a href="#" class="m-0"> Privacy Policy </a></li>
          </ul>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== FOOTER AREA ENDS =======-->

<!--===== JS SCRIPT LINK =======-->
<script src="assets/js/plugins/bootstrap.min.js"></script>
<script src="assets/js/plugins/fontawesome.js"></script>
<script src="assets/js/plugins/aos.js"></script>
<script src="assets/js/plugins/counter.js"></script>
<script src="assets/js/plugins/gsap.min.js"></script>
<script src="assets/js/plugins/ScrollTrigger.min.js"></script>
<script src="assets/js/plugins/Splitetext.js"></script>
<script src="assets/js/plugins/sidebar.js"></script>
<script src="assets/js/plugins/magnific-popup.js"></script>
<script src="assets/js/plugins/mobilemenu.js"></script>
<script src="assets/js/plugins/owlcarousel.min.js"></script>
<script src="assets/js/plugins/gsap-animation.js"></script>
<script src="assets/js/plugins/nice-select.js"></script>
<script src="assets/js/plugins/waypoints.js"></script>
<script src="assets/js/plugins/slick-slider.js"></script>
<script src="assets/js/plugins/circle-progress.js"></script>
<script src="assets/js/main.js"></script>

</body>

<!-- Mirrored from seoc-html-v2.vercel.app/team.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:42:27 GMT -->
</html>